==> kubernetes-model-node-5.10.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1/RuntimeClassBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RuntimeClassBuilder extends io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluentImpl<io.fabric8.kubernetes.api.model.node.v1.RuntimeClassBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.node.v1.RuntimeClass,io.fabric8.kubernetes.api.model.node.v1.RuntimeClassBuilder>{
  public RuntimeClassBuilder() {
    this(false);
  }
  public RuntimeClassBuilder(java.lang.Boolean validationEnabled) {
    this(new RuntimeClass(), validationEnabled);
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluent<?> fluent) {
    this(fluent, false);
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RuntimeClass(), validationEnabled);
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1.RuntimeClass instance) {
    this(fluent, instance, false);
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluent<?> fluent,io.fabric8.kubernetes.api.model.node.v1.RuntimeClass instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withHandler(instance.getHandler()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withOverhead(instance.getOverhead()); 
    fluent.withScheduling(instance.getScheduling()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClass instance) {
    this(instance,false);
  }
  public RuntimeClassBuilder(io.fabric8.kubernetes.api.model.node.v1.RuntimeClass instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withHandler(instance.getHandler()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withOverhead(instance.getOverhead()); 
    this.withScheduling(instance.getScheduling()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.node.v1.RuntimeClassFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.node.v1.RuntimeClass build() {
    RuntimeClass buildable = new RuntimeClass(fluent.getApiVersion(),fluent.getHandler(),fluent.getKind(),fluent.getMetadata(),fluent.getOverhead(),fluent.getScheduling());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RuntimeClassBuilder that = (RuntimeClassBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-node-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/node/v1/RuntimeClassBuilder.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RuntimeClassBuilder extends RuntimeClassFluentImpl<RuntimeClassBuilder> implements VisitableBuilder<RuntimeClass,RuntimeClassBuilder>{
  public RuntimeClassBuilder() {
    this(false);
  }
  public RuntimeClassBuilder(Boolean validationEnabled) {
    this(new RuntimeClass(), validationEnabled);
  }
  public RuntimeClassBuilder(RuntimeClassFluent<?> fluent) {
    this(fluent, false);
  }
  public RuntimeClassBuilder(RuntimeClassFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RuntimeClass(), validationEnabled);
  }
  public RuntimeClassBuilder(RuntimeClassFluent<?> fluent,RuntimeClass instance) {
    this(fluent, instance, false);
  }
  public RuntimeClassBuilder(RuntimeClassFluent<?> fluent,RuntimeClass instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withHandler(instance.getHandler()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withOverhead(instance.getOverhead()); 
    fluent.withScheduling(instance.getScheduling()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RuntimeClassBuilder(RuntimeClass instance) {
    this(instance,false);
  }
  public RuntimeClassBuilder(RuntimeClass instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withHandler(instance.getHandler()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withOverhead(instance.getOverhead()); 
    this.withScheduling(instance.getScheduling()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RuntimeClassFluent<?> fluent;
  Boolean validationEnabled;
  public RuntimeClass build() {
    RuntimeClass buildable = new RuntimeClass(fluent.getApiVersion(),fluent.getHandler(),fluent.getKind(),fluent.getMetadata(),fluent.getOverhead(),fluent.getScheduling());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
